@@ -456,6 +456,15 @@ class TestBaseMethodsTests(BaseMethodsTests):
     def test_argsort(self, data_for_sorting):
         BaseMethodsTests.test_argsort(self, data_for_sorting)
 
+    @xfail_bool_too_few_uniques
+    def test_argmin_argmax(self, data_for_sorting, data_missing_for_sorting, na_value):
+        if PANDAS_GE_1_1_0:
+            BaseMethodsTests.test_argmin_argmax(
+                self, data_for_sorting, data_missing_for_sorting, na_value
+            )
+        else:
+            pass
+
     @pytest.mark.parametrize("ascending", [True, False])
     @xfail_bool_too_few_uniques
     def test_sort_values(self, data_for_sorting, ascending, sort_by_key):
@@ -831,7 +840,7 @@ class TestBaseArithmeticOpsTests(BaseArithmeticOpsTests):
                     other_is_np_int64 = (
                         isinstance(other, pd.Series)
                         and isinstance(other.values, np.ndarray)
-                        and other.dtype.char == "l"
+                        and other.dtype.char in ("q", "l")
                     )
                     if (
                         pa.types.is_integer(arrow_dtype)
